All pastes #262123 Raw Edit

Stuff

public text v1 · immutable
#262123 ·published 2006-11-30 04:55 UTC
rendered paste body
nvidia-installer log file '/var/log/nvidia-installer.log'
creation time: Wed Nov 29 07:11:57 2006

option status:
  license pre-accepted    : false
  update                  : false
  force update            : false
  expert                  : false
  uninstall               : false
  driver info             : false
  precompiled interfaces  : true
  no ncurses color        : false
  query latest version    : false
  OpenGL header files     : true
  no questions            : false
  silent                  : false
  no recursion            : false
  no backup               : false
  kernel module only      : false
  sanity                  : false
  add this kernel         : false
  no runlevel check       : false
  no network              : false
  no ABI note             : false
  no RPMs                 : false
  no kernel module        : false
  force SELinux           : default
  no X server check       : false
  force tls               : (not specified)
  X install prefix        : (not specified)
  X library install path  : (not specified)
  X module install path   : (not specified)
  OpenGL install prefix   : (not specified)
  OpenGL install libdir   : (not specified)
  utility install prefix  : (not specified)
  utility install libdir  : (not specified)
  doc install prefix      : (not specified)
  kernel name             : (not specified)
  kernel include path     : (not specified)
  kernel source path      : (not specified)
  kernel output path      : (not specified)
  kernel install path     : (not specified)
  proc mount point        : /proc
  ui                      : (not specified)
  tmpdir                  : /root/tmp
  ftp mirror              : ftp://download.nvidia.com
  RPM file list           : (not specified)

Using: nvidia-installer ncurses user interface
-> License accepted.
-> There appears to already be a driver installed on your system (version: 1.0-
   9629).  As part of installing this driver (version: 1.0-9629), the existing 
   driver will be uninstalled.  Are you sure you want to continue? ('no' will a
   bort installation) (Answer: Yes)
-> No precompiled kernel interface was found to match your kernel; would you li
   ke the installer to attempt to download a kernel interface for your kernel f
   rom the NVIDIA ftp site (ftp://download.nvidia.com)? (Answer: Yes)
-> No matching precompiled kernel interface was found on the NVIDIA ftp site;
   this means that the installer will need to compile a kernel interface for
   your kernel.
-> Performing CC sanity check with CC="cc".
-> Performing CC version check with CC="cc".
-> Kernel source path: '/lib/modules/2.6.17-5mdv/source'
-> Kernel output path: '/lib/modules/2.6.17-5mdv/build'
-> Performing rivafb check.
-> Performing nvidiafb check.
-> Cleaning kernel module build directory.
   executing: 'cd ./usr/src/nv; make clean'...
   rm -f -f nv.o nv-vm.o os-agp.o os-interface.o os-registry.o nv-i2c.o nv.o nv
   -vm.o os-agp.o os-interface.o os-registry.o nv-i2c.o nvidia.mod.o
   rm -f -f build-in.o nv-linux.o *.d .*.{cmd,flags}
   rm -f -f nvidia.{o,ko,mod.{o,c}} nv_compiler.h *~
   rm -f -f stprof stprof.o symtab.h Modules.symvers
   rm -f -rf .tmp_versions
-> Building kernel module:
   executing: 'cd ./usr/src/nv; make module SYSSRC=/lib/modules/2.6.17-5mdv/sou
   rce SYSOUT=/lib/modules/2.6.17-5mdv/build'...
   
   NVIDIA: calling KBUILD...
   make CC=cc KBUILD_OUTPUT=/lib/modules/2.6.17-5mdv/build KBUILD_VERBOSE=1 -C 
   /lib/modules/2.6.17-5mdv/source SUBDIRS=/root/tmp/selfgz22918/NVIDIA-Linux-x
   86-1.0-9629-pkg1/usr/src/nv modules
   make -C /lib/modules/2.6.17-5mdv/build \
   	KBUILD_SRC=/usr/src/linux-2.6.17-5mdv \
   	KBUILD_EXTMOD="/root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src
   /nv" -f /usr/src/linux-2.6.17-5mdv/Makefile modules
   mkdir -p /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/.tm
   p_versions
   rm -f /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/.tmp_v
   ersions/*
   
     WARNING: Symbol version dump /usr/src/linux-2.6.17-5mdv/Module.symvers
              is missing; modules will have no dependencies and modversions.
   
   make -f /usr/src/linux-2.6.17-5mdv/scripts/Makefile.build obj=/root/tmp/self
   gz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv
   echo \#define NV_COMPILER \"`cc -v 2>&1 | tail -n 1`\" > /root/tmp/selfgz229
   18/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/nv_compiler.h
     cc -Wp,-MD,/root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv
   /.nv.o.d  -nostdinc -isystem /usr/lib/gcc/i586-mandriva-linux-gnu/4.1.1/incl
   ude -D__KERNEL__ -Iinclude -Iinclude2 -I/usr/src/linux-2.6.17-5mdv/include -
   include include/linux/autoconf.h   -I/root/tmp/selfgz22918/NVIDIA-Linux-x86-
   1.0-9629-pkg1/usr/src/nv -Wall -Wundef -Wstrict-prototypes -Wno-trigraphs -f
   no-strict-aliasing -fno-common -O2 -fno-omit-frame-pointer -fno-optimize-sib
   ling-calls -pipe -msoft-float -mpreferred-stack-boundary=2 -march=i686 -ffre
   estanding -I/usr/src/linux-2.6.17-5mdv/include/asm-i386/mach-default -Iinclu
   de/asm-i386/mach-default -Wdeclaration-after-statement -Wno-pointer-sign  -I
   /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv -Wall -Wimpl
   icit -Wreturn-type -Wswitch -Wformat -Wchar-subscripts -Wparentheses -Wpoint
   er-arith -Wno-multichar -Werror -O -fno-common -msoft-float -MD -Wsign-compa
   re -Wno-cast-qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE -DN
   VRM -DNV_MAJOR_VERSION=1 -DNV_MINOR_VERSION=0 -DNV_
   PATCHLEVEL=9629 -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM -DNV_MULTI
   PLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_MAX_MAP_CO
   UNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_IRQ_HANDLER_WITH_PTREGS_PRESENT -
   DNV_PCI_CHOOSE_STATE_PRESENT -DNV_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BR
   EAKPOINT_PRESENT -DNV_REMAP_PFN_RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT 
   -DNV_VMAP_4_PRESENT -DMODULE -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_
   STR(nv)"  -D"KBUILD_MODNAME=KBUILD_STR(nvidia)" -c -o /root/tmp/selfgz22918/
   NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/nv.o /root/tmp/selfgz22918/NVIDIA-
   Linux-x86-1.0-9629-pkg1/usr/src/nv/nv.c
   In file included from include/linux/dmapool.h:14,
                    from include/linux/pci.h:559,
                    from /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/u
   sr/src/nv/nv-linux.h:77,
                    from /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/u
   sr/src/nv/nv.c:14:
   include/asm/io.h: In function 'check_signature':
   include/asm/io.h:246: warning: wrong type argument to increment
     cc -Wp,-MD,/root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv
   /.nv-vm.o.d  -nostdinc -isystem /usr/lib/gcc/i586-mandriva-linux-gnu/4.1.1/i
   nclude -D__KERNEL__ -Iinclude -Iinclude2 -I/usr/src/linux-2.6.17-5mdv/includ
   e -include include/linux/autoconf.h   -I/root/tmp/selfgz22918/NVIDIA-Linux-x
   86-1.0-9629-pkg1/usr/src/nv -Wall -Wundef -Wstrict-prototypes -Wno-trigraphs
   -fno-strict-aliasing -fno-common -O2 -fno-omit-frame-pointer -fno-optimize-s
   ibling-calls -pipe -msoft-float -mpreferred-stack-boundary=2 -march=i686 -ff
   reestanding -I/usr/src/linux-2.6.17-5mdv/include/asm-i386/mach-default -Iinc
   lude/asm-i386/mach-default -Wdeclaration-after-statement -Wno-pointer-sign  
   -I/root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv -Wall -Wim
   plicit -Wreturn-type -Wswitch -Wformat -Wchar-subscripts -Wparentheses -Wpoi
   nter-arith -Wno-multichar -Werror -O -fno-common -msoft-float -MD -Wsign-com
   pare -Wno-cast-qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE -
   DNVRM
    -DNV_MAJOR_VERSION=1 -DNV_MINOR_VERSION=0 -DNV_PATCHLEVEL=9629 -UDEBUG -U_D
   EBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -
   DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_
   T_PRESENT -DNV_IRQ_HANDLER_WITH_PTREGS_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT
   -DNV_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_REMAP_P
   FN_RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_VMAP_4_PRESENT -DMODULE 
   -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(nv_vm)"  -D"KBUILD_MODNAM
   E=KBUILD_STR(nvidia)" -c -o /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-
   pkg1/usr/src/nv/nv-vm.o /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1
   /usr/src/nv/nv-vm.c
   In file included from include/linux/dmapool.h:14,
                    from include/linux/pci.h:559,
                    from /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/u
   sr/src/nv/nv-linux.h:77,
                    from /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/u
   sr/src/nv/nv-vm.c:14:
   include/asm/io.h: In function 'check_signature':
   include/asm/io.h:246: warning: wrong type argument to increment
     cc -Wp,-MD,/root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv
   /.os-agp.o.d  -nostdinc -isystem /usr/lib/gcc/i586-mandriva-linux-gnu/4.1.1/
   include -D__KERNEL__ -Iinclude -Iinclude2 -I/usr/src/linux-2.6.17-5mdv/inclu
   de -include include/linux/autoconf.h   -I/root/tmp/selfgz22918/NVIDIA-Linux-
   x86-1.0-9629-pkg1/usr/src/nv -Wall -Wundef -Wstrict-prototypes -Wno-trigraph
   s -fno-strict-aliasing -fno-common -O2 -fno-omit-frame-pointer -fno-optimize
   -sibling-calls -pipe -msoft-float -mpreferred-stack-boundary=2 -march=i686 -
   ffreestanding -I/usr/src/linux-2.6.17-5mdv/include/asm-i386/mach-default -Ii
   nclude/asm-i386/mach-default -Wdeclaration-after-statement -Wno-pointer-sign
    -I/root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv -Wall -Wi
   mplicit -Wreturn-type -Wswitch -Wformat -Wchar-subscripts -Wparentheses -Wpo
   inter-arith -Wno-multichar -Werror -O -fno-common -msoft-float -MD -Wsign-co
   mpare -Wno-cast-qual 
   -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE -DNVRM -DNV_MAJOR_VER
   SION=1 -DNV_MINOR_VERSION=0 -DNV_PATCHLEVEL=9629 -UDEBUG -U_DEBUG -DNDEBUG -
   DNV_SIGNAL_STRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLA
   SS_PRESENT -DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_
   IRQ_HANDLER_WITH_PTREGS_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT -DNV_VM_INSERT
   _PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_REMAP_PFN_RANGE_PRESE
   NT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_VMAP_4_PRESENT -DMODULE -D"KBUILD_STR(
   s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(os_agp)"  -D"KBUILD_MODNAME=KBUILD_STR(
   nvidia)" -c -o /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/
   nv/os-agp.o /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/
   os-agp.c
   In file included from include/linux/dmapool.h:14,
                    from include/linux/pci.h:559,
                    from /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/u
   sr/src/nv/nv-linux.h:77,
                    from /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/u
   sr/src/nv/os-agp.c:24:
   include/asm/io.h: In function 'check_signature':
   include/asm/io.h:246: warning: wrong type argument to increment
     cc -Wp,-MD,/root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv
   /.os-interface.o.d  -nostdinc -isystem /usr/lib/gcc/i586-mandriva-linux-gnu/
   4.1.1/include -D__KERNEL__ -Iinclude -Iinclude2 -I/usr/src/linux-2.6.17-5mdv
   /include -include include/linux/autoconf.h   -I/root/tmp/selfgz22918/NVIDIA-
   Linux-x86-1.0-9629-pkg1/usr/src/nv -Wall -Wundef -Wstrict-prototypes -Wno-tr
   igraphs -fno-strict-aliasing -fno-common -O2 -fno-omit-frame-pointer -fno-op
   timize-sibling-calls -pipe -msoft-float -mpreferred-stack-boundary=2 -march=
   i686 -ffreestanding -I/usr/src/linux-2.6.17-5mdv/include/asm-i386/mach-defau
   lt -Iinclude/asm-i386/mach-default -Wdeclaration-after-statement -Wno-pointe
   r-sign  -I/root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv -W
   all -Wimplicit -Wreturn-type -Wswitch -Wformat -Wchar-subscripts -Wparenthes
   es -Wpointer-arith -Wno-multichar
    -Werror -O -fno-common -msoft-float -MD -Wsign-compare -Wno-cast-qual -Wno-
   error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE -DNVRM -DNV_MAJOR_VERSION=
   1 -DNV_MINOR_VERSION=0 -DNV_PATCHLEVEL=9629 -UDEBUG -U_DEBUG -DNDEBUG -DNV_S
   IGNAL_STRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PR
   ESENT -DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_IRQ_H
   ANDLER_WITH_PTREGS_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT -DNV_VM_INSERT_PAGE
   _PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_REMAP_PFN_RANGE_PRESENT -D
   NV_CHANGE_PAGE_ATTR_PRESENT -DNV_VMAP_4_PRESENT -DMODULE -D"KBUILD_STR(s)=#s
   " -D"KBUILD_BASENAME=KBUILD_STR(os_interface)"  -D"KBUILD_MODNAME=KBUILD_STR
   (nvidia)" -c -o /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src
   /nv/os-interface.o /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/
   src/nv/os-interface.c
   In file included from include/linux/dmapool.h:14,
                    from include/linux/pci.h:559,
                    from /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/u
   sr/src/nv/nv-linux.h:77,
                    from /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/u
   sr/src/nv/os-interface.c:26:
   include/asm/io.h: In function 'check_signature':
   include/asm/io.h:246: warning: wrong type argument to increment
     cc -Wp,-MD,/root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv
   /.os-registry.o.d  -nostdinc -isystem /usr/lib/gcc/i586-mandriva-linux-gnu/4
   .1.1/include -D__KERNEL__ -Iinclude -Iinclude2 -I/usr/src/linux-2.6.17-5mdv/
   include -include include/linux/autoconf.h   -I/root/tmp/selfgz22918/NVIDIA-L
   inux-x86-1.0-9629-pkg1/usr/src/nv -Wall -Wundef -Wstrict-prototypes -Wno-tri
   graphs -fno-strict-aliasing -fno-common -O2 -fno-omit-frame-pointer -fno-opt
   imize-sibling-calls -pipe -msoft-float -mpreferred-stack-boundary=2 -march=i
   686 -ffreestanding -I/usr/src/linux-2.6.17-5mdv/include/asm-i386/mach-defaul
   t -Iinclude/asm-i386/mach-default -Wdeclaration-after-statement -Wno-pointer
   -sign  -I/root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv -Wa
   ll -Wimplicit 
   -Wreturn-type -Wswitch -Wformat -Wchar-subscripts -Wparentheses -Wpointer-ar
   ith -Wno-multichar -Werror -O -fno-common -msoft-float -MD -Wsign-compare -W
   no-cast-qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE -DNVRM -
   DNV_MAJOR_VERSION=1 -DNV_MINOR_VERSION=0 -DNV_PATCHLEVEL=9629 -UDEBUG -U_DEB
   UG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DN
   V_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_
   PRESENT -DNV_IRQ_HANDLER_WITH_PTREGS_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT -
   DNV_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_REMAP_PF
   N_RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_VMAP_4_PRESENT -DMODULE -
   D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(os_registry)"  -D"KBUILD_M
   ODNAME=KBUILD_STR(nvidia)" -c -o /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-
   9629-pkg1/usr/src/nv/os-registry.o /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.
   0-9629-pkg1/usr/src/nv/os-registry.c
   In file included from include/linux/dmapool.h:14,
                    from include/linux/pci.h:559,
                    from /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/u
   sr/src/nv/nv-linux.h:77,
                    from /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/u
   sr/src/nv/os-registry.c:14:
   include/asm/io.h: In function 'check_signature':
   include/asm/io.h:246: warning: wrong type argument to increment
     cc -Wp,-MD,/root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv
   /.nv-i2c.o.d  -nostdinc -isystem /usr/lib/gcc/i586-mandriva-linux-gnu/4.1.1/
   include -D__KERNEL__ -Iinclude -Iinclude2 -I/usr/src/linux-2.6.17-5mdv/inclu
   de -include include/linux/autoconf.h   -I/root/tmp/selfgz22918/NVIDIA-Linux-
   x86-1.0-9629-pkg1/usr/src/nv -Wall -Wundef -Wstrict-prototypes -Wno-trigraph
   s -fno-strict-aliasing -fno-common -O2 -fno-omit-frame-pointer -fno-optimize
   -sibling-calls -pipe -msoft-float -mpreferred-stack-boundary=2 -march=i686 -
   ffreestanding -I/usr/src/linux-2.6.17-5mdv/include/asm-i386/mach-default -Ii
   nclude/asm-i386/mach-default -Wdeclaration-after-statement -Wno-pointer-sign
     -I/root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv -Wall -W
   implicit -Wreturn-type -Wswitch -Wformat -Wchar-subscripts -Wparentheses -Wp
   ointer-arith -Wno-multichar -Werror -O -fno-common -msoft-float -MD -Wsign-c
   ompare -Wno-cast-qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE
   -DNVRM -DNV_MAJOR_VERSION=1 -DNV_MINOR_VERSION=0 -DNV_PATCHLEVEL=9629 -UDEBU
   G -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRE
   SENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_ME
   SSAGE_T_PRESENT -DNV_IRQ_HANDLER_WITH_PTREGS_PRESENT -DNV_PCI_CHOOSE_STATE_P
   RESENT -DNV_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_
   REMAP_PFN_RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_VMAP_4_PRESENT -D
   MODULE -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(nv_i2c)"  -D"KBUIL
   D_MODNAME=KBUILD_STR(nvidia)" -c -o /root/tmp/selfgz22918/NVIDIA-Linux-x86-1
   .0-9629-pkg1/usr/src/nv/nv-i2c.o /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-
   9629-pkg1/usr/src/nv/nv-i2c.c
   In file included from include/linux/dmapool.h:14,
                    from include/linux/pci.h:559,
                    from /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/u
   sr/src/nv/nv-linux.h:77,
                    from /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/u
   sr/src/nv/nv-i2c.c:8:
   include/asm/io.h: In function 'check_signature':
   include/asm/io.h:246: warning: wrong type argument to increment
     ld -m elf_i386 -m elf_i386  -r -o /root/tmp/selfgz22918/NVIDIA-Linux-x86-1
   .0-9629-pkg1/usr/src/nv/nvidia.o /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-
   9629-pkg1/usr/src/nv/nv-kernel.o /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-
   9629-pkg1/usr/src/nv/nv.o /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pk
   g1/usr/src/nv/nv-vm.o /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/u
   sr/src/nv/os-agp.o /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/
   src/nv/os-interface.o /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/u
   sr/src/nv/os-registry.o /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1
   /usr/src/nv/
   nv-i2c.o
     Building modules, stage 2.
   make -rR -f /usr/src/linux-2.6.17-5mdv/scripts/Makefile.modpost
     scripts/mod/modpost   -i /usr/src/linux-2.6.17-5mdv/Module.symvers -I /roo
   t/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/Modules.symvers 
   -o /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/Modules.s
   ymvers /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/nvidi
   a.o
     cc -Wp,-MD,/root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv
   /.nvidia.mod.o.d  -nostdinc -isystem /usr/lib/gcc/i586-mandriva-linux-gnu/4.
   1.1/include -D__KERNEL__ -Iinclude -Iinclude2 -I/usr/src/linux-2.6.17-5mdv/i
   nclude -include include/linux/autoconf.h  -I/usr/src/linux-2.6.17-5mdv/ -I -
   Wall -Wundef -Wstrict-prototypes -Wno-trigraphs -fno-strict-aliasing -fno-co
   mmon -O2 -fno-omit-frame-pointer -fno-optimize-sibling-calls -pipe -msoft-fl
   oat -mpreferred-stack-boundary=2 -march=i686 -ffreestanding -I/usr/src/linux
   -2.6.17-5mdv/include/asm-i386/mach-default -Iinclude/asm-i386/mach-default -
   Wdecla
   ration-after-statement -Wno-pointer-sign  -D"KBUILD_STR(s)=#s" -D"KBUILD_BAS
   ENAME=KBUILD_STR(nvidia)"  -D"KBUILD_MODNAME=KBUILD_STR(nvidia)" -DMODULE -c
   -o /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/nvidia.mo
   d.o /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/nvidia.m
   od.c
     ld -m elf_i386 -m elf_i386 -r -o /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.
   0-9629-pkg1/usr/src/nv/nvidia.ko /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-
   9629-pkg1/usr/src/nv/nvidia.o /root/tmp/selfgz22918/NVIDIA-Linux-x86-1.0-962
   9-pkg1/usr/src/nv/nvidia.mod.o
   NVIDIA: left KBUILD.
-> done.
-> Kernel module compilation complete.
-> Kernel messages:
   NFSD: starting 90-second grace period
   Netfilter messages via NETLINK v0.30.
   ip_conntrack version 2.4 (4091 buckets, 32728 max) - 224 bytes per conntrack
   NVRM: loading NVIDIA Linux x86 Kernel Module  1.0-9629  Wed Nov  1 19:30:07
   PST 2006
   agpgart: Found an AGP 2.0 compliant device at 0000:00:00.0.
   agpgart: Putting AGP V2 device at 0000:00:00.0 into 4x mode
   agpgart: Putting AGP V2 device at 0000:01:00.0 into 4x mode
   ClusterIP Version 0.8 loaded successfully
   ipt_recent v0.3.1: Stephen Frost <sfrost@snowman.net>. 
   http://snowman.net/projects/ipt_recent/
   netfilter PSD loaded - (c) astaro AG
   IFWLOG: register target
   eth0: no IPv6 routers present
   Shorewall:net2all:DROP:IN=eth0 OUT= MAC= SRC=192.168.1.100 DST=192.168.1.255
   LEN=44 TOS=0x00 PREC=0x00 TTL=64 ID=0 DF PROTO=UDP SPT=32781 DPT=7741 LEN=24
   
   Shorewall:net2all:DROP:IN=eth0 OUT= MAC= SRC=192.168.1.100 DST=192.168.1.255
   LEN=44 TOS=0x00 PREC=0x00 TTL=64 ID=0 DF PROTO=UDP SPT=32789 DPT=7741 LEN=24
   
   Shorewall:net2all:DROP:IN=eth0 OUT= MAC= SRC=192.168.1.100 DST=192.168.1.255
   LEN=44 TOS=0x00 PREC=0x00 TTL=64 ID=0 DF PROTO=UDP SPT=32803 DPT=7741 LEN=24
   
   Shorewall:net2all:DROP:IN=eth0 OUT= MAC= SRC=192.168.1.100 DST=192.168.1.255
   LEN=44 TOS=0x00 PREC=0x00 TTL=64 ID=0 DF PROTO=UDP SPT=32833 DPT=7741 LEN=24
   
   Shorewall:net2all:DROP:IN=eth0 OUT= MAC= SRC=192.168.1.100 DST=192.168.1.255
   LEN=44 TOS=0x00 PREC=0x00 TTL=64 ID=0 DF PROTO=UDP SPT=32886 DPT=7741 LEN=24
   
   Shorewall:net2all:DROP:IN=eth0 OUT= MAC= SRC=192.168.1.100 DST=192.168.1.255
   LEN=44 TOS=0x00 PREC=0x00 TTL=64 ID=0 DF PROTO=UDP SPT=33008 DPT=7741 LEN=24
   
   Shorewall:net2all:DROP:IN=eth0 OUT= MAC= SRC=192.168.1.100 DST=192.168.1.255
   LEN=44 TOS=0x00 PREC=0x00 TTL=64 ID=0 DF PROTO=UDP SPT=33338 DPT=7741 LEN=24
   
   Shorewall:net2all:DROP:IN=eth0 OUT= MAC= SRC=192.168.1.100 DST=192.168.1.255
   LEN=44 TOS=0x00 PREC=0x00 TTL=64 ID=0 DF PROTO=UDP SPT=33454 DPT=7741 LEN=24
   
   Shorewall:net2all:DROP:IN=eth0 OUT= MAC= SRC=192.168.1.100 DST=192.168.1.255
   LEN=44 TOS=0x00 PREC=0x00 TTL=64 ID=0 DF PROTO=UDP SPT=33576 DPT=7741 LEN=24
   
   Shorewall:net2all:DROP:IN=eth0 OUT= MAC= SRC=192.168.1.100 DST=192.168.1.255
   LEN=44 TOS=0x00 PREC=0x00 TTL=64 ID=0 DF PROTO=UDP SPT=33701 DPT=7741 LEN=24
   
   Shorewall:net2all:DROP:IN=eth0 OUT= MAC= SRC=192.168.1.100 DST=192.168.1.255
   LEN=44 TOS=0x00 PREC=0x00 TTL=64 ID=0 DF PROTO=UDP SPT=33826 DPT=7741 LEN=24
   
   Shorewall:net2all:DROP:IN=eth0 OUT= MAC= SRC=192.168.1.100 DST=192.168.1.255
   LEN=44 TOS=0x00 PREC=0x00 TTL=64 ID=0 DF PROTO=UDP SPT=33947 DPT=7741 LEN=24
   
   NVRM: loading NVIDIA Linux x86 Kernel Module  1.0-9629  Wed Nov  1 19:30:07
   PST 2006
WARNING: You appear to be using a modular X.Org release, but nvidia-installer
         was unable to determine the correct X library installation path with
         the `pkg-config` utility.  Please install the X.Org SDK/development
         package for your distribution.
WARNING: nvidia-installer was unable to determine the correct X library
         installation path and will install the NVIDIA X libraries to
         '/usr/lib'.
WARNING: You appear to be using a modular X.Org release, but nvidia-installer
         was unable to determine the correct X module installation path with
         the `pkg-config` utility.  Please install the X.Org SDK/development
         package for your distribution.
WARNING: nvidia-installer was unable to determine the correct X module
         installation path and will install the NVIDIA X driver components to
         '/usr/lib/xorg/modules'.  If X fails to find the NVIDIA X driver
         module, please correct any `pkg-config` problems warned about earlier
         and reinstall the driver.
-> Installing both new and classic TLS OpenGL libraries.
-> Parsing log file:
-> done.
-> Validating previous installation:
-> done.
-> Uninstalling NVIDIA Accelerated Graphics Driver for Linux-x86 (1.0-9629):
-> done.
-> Uninstallation of existing driver: NVIDIA Accelerated Graphics Driver for
   Linux-x86 (1.0-9629) is complete.
-> Searching for conflicting X files:
-> done.
-> Searching for conflicting OpenGL files:
-> done.
-> Installing 'NVIDIA Accelerated Graphics Driver for Linux-x86' (1.0-9629):
   executing: '/sbin/ldconfig'...
   executing: '/sbin/depmod -aq'...
-> done.
-> Driver file installation is complete.
-> Running post-install sanity check:
-> done.
-> Post-install sanity check passed.
-> Shared memory test passed.
-> Running runtime sanity check:
-> done.
-> Runtime sanity check passed.
-> Would you like to run the nvidia-xconfig utility to automatically update you
   r X configuration file so that the NVIDIA X driver will be used when you res
   tart X?  Any pre-existing X configuration file will be backed up. (Answer: N
   o)
-> Installation of the NVIDIA Accelerated Graphics Driver for Linux-x86
   (version: 1.0-9629) is now complete.  Please update your XF86Config or
   xorg.conf file as appropriate; see the file
   /usr/share/doc/NVIDIA_GLX-1.0/README.txt for details.